@@ -2,6 +2,13 @@ import aiohttp
 import asyncio
 
 async def load(host):
+    """
+    Load the nodeinfo of the given host
+
+    Raises:
+    - ValueError if the provided host does not implement the Nodeinfo protocol
+    - IOError if the node info protocol is implemented incorrectly.
+    """
 
     async with aiohttp.ClientSession() as session:
         nodeinfo_uri = await get_nodeinfo_uri(host, session)
@@ -12,7 +19,7 @@ async def load(host):
                 raise ValueError("NodeInfo Endpoint returns an error: " + response.status)
 
             if response.content_type != "application/json":
-                raise ValueError("NodeInfo endpoint returned content of type: " + response.content_type)
+                raise IOError("NodeInfo endpoint returned content of type: " + response.content_type)
 
             info = await response.json()
             return info
